@@ -5,6 +5,31 @@
  * @package phpMyAdmin-Navigation
  */
 
+/**
+ * updates the tree state in sessionStorage
+ *
+ * @returns void
+ */
+function navTreeStateUpdate() {
+    // update if session storage is supported
+    if (isStorageSupported('sessionStorage')) {
+        var storage = window.sessionStorage;
+        // try catch necessary here to detect whether
+        // content to be stored exceeds storage capacity
+        try {
+            storage.setItem('navTreePaths', JSON.stringify(traverseNavigationForPaths()));
+            storage.setItem('server', PMA_commonParams.get('server'));
+            storage.setItem('token', PMA_commonParams.get('token'));
+        } catch(error) {
+            // storage capacity exceeded & old navigation tree
+            // state is no more valid, so remove it
+            storage.removeItem('navTreePaths');
+            storage.removeItem('server');
+            storage.removeItem('token');
+        }
+    }
+}
+
 /**
  * Loads child items of a node and executes a given callback
  *
@@ -305,7 +330,6 @@ $(function () {
     $(document).on('focus', '#pma_navigation_tree li.fast_filter input.searchClause', PMA_fastFilter.events.focus);
     $(document).on('blur', '#pma_navigation_tree li.fast_filter input.searchClause', PMA_fastFilter.events.blur);
     $(document).on('keyup', '#pma_navigation_tree li.fast_filter input.searchClause', PMA_fastFilter.events.keyup);
-    $(document).on('mouseover', '#pma_navigation_tree li.fast_filter input.searchClause', PMA_fastFilter.events.mouseover);
 
     /**
      * Ajax handler for pagination
@@ -414,6 +438,7 @@ $(function () {
     $(document).on('click', 'a.hideNavItem.ajax', function (event) {
         event.preventDefault();
         $.ajax({
+            type: 'POST',
             url: $(this).attr('href') + '&ajax_request=true',
             success: function (data) {
                 if (typeof data !== 'undefined' && data.success === true) {
@@ -461,6 +486,7 @@ $(function () {
         var $tr = $(this).parents('tr');
         var $msg = PMA_ajaxShowMessage();
         $.ajax({
+            type: 'POST',
             url: $(this).attr('href') + '&ajax_request=true',
             success: function (data) {
                 PMA_ajaxRemoveMessage($msg);
@@ -536,31 +562,6 @@ $(function () {
     }
 });
 
-/**
- * updates the tree state in sessionStorage
- *
- * @returns void
- */
-function navTreeStateUpdate() {
-    // update if session storage is supported
-    if (isStorageSupported('sessionStorage')) {
-        var storage = window.sessionStorage;
-        // try catch necessary here to detect whether
-        // content to be stored exceeds storage capacity
-        try {
-            storage.setItem('navTreePaths', JSON.stringify(traverseNavigationForPaths()));
-            storage.setItem('server', PMA_commonParams.get('server'));
-            storage.setItem('token', PMA_commonParams.get('token'));
-        } catch(error) {
-            // storage capacity exceeded & old navigation tree
-            // state is no more valid, so remove it
-            storage.removeItem('navTreePaths');
-            storage.removeItem('server');
-            storage.removeItem('token');
-        }
-    }
-}
-
 /**
  * Expands a node in navigation tree.
  *
@@ -1307,26 +1308,6 @@ var PMA_fastFilter = {
                 $obj.data('fastFilter').restore();
             }
         },
-        mouseover: function (event) {
-            var message = '';
-            if ($(this).closest('li.fast_filter').is('.db_fast_filter')) {
-                message = PMA_messages.strHoverDbFastFilter;
-            } else {
-                var node_type = $(this).siblings("input[name='pos2_name']").val();
-                var node_name = PMA_messages.strTables;
-                if (node_type == 'views') {
-                    node_name = PMA_messages.strViews;
-                } else if (node_type == 'procedures') {
-                    node_name = PMA_messages.strProcedures;
-                } else if (node_type == 'functions') {
-                    node_name = PMA_messages.strFunctions;
-                } else if (node_type == 'events') {
-                    node_name = PMA_messages.strEvents;
-                }
-                message = PMA_sprintf(PMA_messages.strHoverFastFilter, node_name);
-            }
-            PMA_tooltip($(this), 'input', message);
-        },
         keyup: function (event) {
             var $obj = $(this).closest('div.list_container');
             var str = '';
