@@ -396,7 +396,7 @@ RTE.COMMON = {
              *          the AJAX message shown to the user
              */
             var $msg = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
-            $.get(url, {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
+            $.post(url, {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
                 if (data.success === true) {
                     /**
                      * @var $table Object containing reference
@@ -445,7 +445,7 @@ RTE.COMMON = {
                 } else {
                     PMA_ajaxShowMessage(data.error, false);
                 }
-            }); // end $.get()
+            }); // end $.post()
         }); // end $.PMA_confirm()
     },
 
@@ -470,7 +470,7 @@ RTE.COMMON = {
                  * @var $curr_row Object containing reference to the current row
                  */
                 var $curr_row = $anchor.parents('tr');
-                $.get($anchor.attr('href'), {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
+                $.post($anchor.attr('href'), {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
                     returnCount++;
                     if (data.success === true) {
                         /**
@@ -527,7 +527,7 @@ RTE.COMMON = {
                             PMA_reloadNavigation();
                         }
                     }
-                }); // end $.get()
+                }); // end $.post()
             }); // end drop_anchors.each()
         }); // end $.PMA_confirm()
     }
@@ -599,6 +599,48 @@ RTE.ROUTINE = {
             $('table.rte_table').last().find('select[name=item_returnopts_text]'),
             $('table.rte_table').last().find('select[name=item_returnopts_num]')
         );
+        // Allow changing parameter order
+        $('.routine_params_table tbody').sortable({
+            containment: '.routine_params_table tbody',
+            handle: '.dragHandle',
+            stop: function(event, ui) {
+                that.reindexParameters();
+            },
+        });
+    },
+    /**
+     * Reindexes the parameters after dropping a parameter or reordering parameters
+     */
+    reindexParameters: function () {
+        /**
+         * @var index Counter used for reindexing the input
+         *            fields in the routine parameters table
+         */
+        var index = 0;
+        $('table.routine_params_table tbody').find('tr').each(function () {
+            $(this).find(':input').each(function () {
+                /**
+                 * @var inputname The value of the name attribute of
+                 *                the input field being reindexed
+                 */
+                var inputname = $(this).attr('name');
+                if (inputname.substr(0, 14) === 'item_param_dir') {
+                    $(this).attr('name', inputname.substr(0, 14) + '[' + index + ']');
+                } else if (inputname.substr(0, 15) === 'item_param_name') {
+                    $(this).attr('name', inputname.substr(0, 15) + '[' + index + ']');
+                } else if (inputname.substr(0, 15) === 'item_param_type') {
+                    $(this).attr('name', inputname.substr(0, 15) + '[' + index + ']');
+                } else if (inputname.substr(0, 17) === 'item_param_length') {
+                    $(this).attr('name', inputname.substr(0, 17) + '[' + index + ']');
+                    $(this).attr('id', 'item_param_length_' + index);
+                } else if (inputname.substr(0, 20) === 'item_param_opts_text') {
+                    $(this).attr('name', inputname.substr(0, 20) + '[' + index + ']');
+                } else if (inputname.substr(0, 19) === 'item_param_opts_num') {
+                    $(this).attr('name', inputname.substr(0, 19) + '[' + index + ']');
+                }
+            });
+            index++;
+        });
     },
     /**
      * Overriding the validateCustom() function defined in common.js
@@ -776,7 +818,7 @@ RTE.ROUTINE = {
          *          the AJAX message shown to the user
          */
         var $msg = PMA_ajaxShowMessage();
-        $.get($this.attr('href'), {'ajax_request': true}, function (data) {
+        $.post($this.attr('href'), {'ajax_request': true}, function (data) {
             if (data.success === true) {
                 PMA_ajaxRemoveMessage($msg);
                 // If 'data.dialog' is true we show a dialog with a form
@@ -860,7 +902,7 @@ RTE.ROUTINE = {
             } else {
                 PMA_ajaxShowMessage(data.error, false);
             }
-        }); // end $.get()
+        }); // end $.post()
     }
 };
 
@@ -1022,34 +1064,6 @@ $(function () {
         $(this).parent().parent().remove();
         // After removing a parameter, the indices of the name attributes in
         // the input fields lose the correct order and need to be reordered.
-        /**
-         * @var index Counter used for reindexing the input
-         *            fields in the routine parameters table
-         */
-        var index = 0;
-        $(this).closest('div.ui-dialog').find('table.routine_params_table').find('tr').has('td').each(function () {
-            $(this).find(':input').each(function () {
-                /**
-                 * @var inputname The value of the name attribute of
-                 *                the input field being reindexed
-                 */
-                var inputname = $(this).attr('name');
-                if (inputname.substr(0, 14) === 'item_param_dir') {
-                    $(this).attr('name', inputname.substr(0, 14) + '[' + index + ']');
-                } else if (inputname.substr(0, 15) === 'item_param_name') {
-                    $(this).attr('name', inputname.substr(0, 15) + '[' + index + ']');
-                } else if (inputname.substr(0, 15) === 'item_param_type') {
-                    $(this).attr('name', inputname.substr(0, 15) + '[' + index + ']');
-                } else if (inputname.substr(0, 17) === 'item_param_length') {
-                    $(this).attr('name', inputname.substr(0, 17) + '[' + index + ']');
-                    $(this).attr('id', 'item_param_length_' + index);
-                } else if (inputname.substr(0, 20) === 'item_param_opts_text') {
-                    $(this).attr('name', inputname.substr(0, 20) + '[' + index + ']');
-                } else if (inputname.substr(0, 19) === 'item_param_opts_num') {
-                    $(this).attr('name', inputname.substr(0, 19) + '[' + index + ']');
-                }
-            });
-            index++;
-        });
+        RTE.ROUTINE.reindexParameters();
     }); // end $(document).on()
 }); // end of $()
