@@ -168,7 +168,10 @@ function verificationsAfterFieldChange(urlField, multi_edit, theType)
     var $this_function = $("select[name='funcs[multi_edit][" + multi_edit + "][" +
         urlField + "]']");
     var function_selected = false;
-    if (typeof $this_function.val() !== 'undefined' && $this_function.val().length > 0) {
+    if (typeof $this_function.val() !== 'undefined' &&
+        $this_function.val() !== null &&
+        $this_function.val().length > 0
+    ) {
         function_selected = true;
     }
 
@@ -345,9 +348,9 @@ AJAX.registerOnload('tbl_change.js', function () {
                 return false;
             }
 
-            return !(value.substring(0, 3) === "MD5"
-            && typeof options.data('maxlength') !== 'undefined'
-            && options.data('maxlength') < 32);
+            return !(value.substring(0, 3) === "MD5" &&
+                typeof options.data('maxlength') !== 'undefined' &&
+                options.data('maxlength') < 32);
         });
 
         jQuery.validator.addMethod("validationFunctionForDateTime", function(value, element, options) {
@@ -376,8 +379,8 @@ AJAX.registerOnload('tbl_change.js', function () {
                     return isDate(dt_value, tmstmp);
                 }
 
-                return isDate(dt_value.substring(0, dv), tmstmp)
-                    && isTime(dt_value.substring(dv + 1));
+                return isDate(dt_value.substring(0, dv), tmstmp) &&
+                    isTime(dt_value.substring(dv + 1));
             }
         });
         /*
@@ -434,7 +437,7 @@ AJAX.registerOnload('tbl_change.js', function () {
      * "Continue insertion" are handled in the "Continue insertion" code
      *
      */
-    $(document).on('click', 'input.checkbox_null', function (e) {
+    $(document).on('click', 'input.checkbox_null', function () {
         nullify(
             // use hidden fields populated by tbl_change.php
             $(this).siblings('.nullify_code').val(),
@@ -450,7 +453,7 @@ AJAX.registerOnload('tbl_change.js', function () {
      * when we are in edit-mode, and not in insert-mode(no previous value
      * available).
      */
-    $('select[name="submit_type"]').bind('change', function (e) {
+    $('select[name="submit_type"]').bind('change', function () {
         var thisElemSubmitTypeVal = $(this).val();
         var $table = $('table.insertRowTable');
         var auto_increment_column = $table.find('input[name^="auto_increment"]');
@@ -562,7 +565,7 @@ AJAX.registerOnload('tbl_change.js', function () {
                         // will change
                         .data('hashed_field', hashed_field)
                         .data('new_row_index', new_row_index)
-                        .bind('change', function (e) {
+                        .bind('change', function () {
                             var $changed_element = $(this);
                             verificationsAfterFieldChange(
                                 $changed_element.data('hashed_field'),
@@ -581,7 +584,7 @@ AJAX.registerOnload('tbl_change.js', function () {
                         // will be clicked
                         .data('hashed_field', hashed_field)
                         .data('new_row_index', new_row_index)
-                        .bind('click', function (e) {
+                        .bind('click', function () {
                             var $changed_element = $(this);
                             nullify(
                                 $changed_element.siblings('.nullify_code').val(),
