@@ -632,12 +632,6 @@ $strConfigServers_SessionTimeZone_desc = __(
 $strConfigServers_auth_http_realm_desc
     = __('HTTP Basic Auth Realm name to display when doing HTTP Auth.');
 $strConfigServers_auth_http_realm_name = __('HTTP Realm');
-$strConfigServers_auth_swekey_config_desc = __(
-    'The path for the config file for SweKey hardware '
-    . 'authentication (not located in your document root; suggested: '
-    . '/etc/swekey.conf).'
-);
-$strConfigServers_auth_swekey_config_name = __('SweKey config file');
 $strConfigServers_auth_type_desc = __('Authentication method to use.');
 $strConfigServers_auth_type_name = __('Authentication type');
 $strConfigServers_bookmarktable_desc = __(
@@ -699,8 +693,8 @@ $strConfigServers_savedsearches_desc = __(
     'Leave blank for no QBE saved searches support, suggested: '
     . '[kbd]pma__savedsearches[/kbd].'
 );
-$strConfigServers_savedsearches_name = __('Export templates table');
-$strConfigServers_savedsearches_desc = __(
+$strConfigServers_export_templates_name = __('Export templates table');
+$strConfigServers_export_templates_desc = __(
     'Leave blank for no export template support, suggested: '
     . '[kbd]pma__export_templates[/kbd].'
 );
@@ -811,8 +805,8 @@ $strConfigServers_userconfig_desc = __(
 $strConfigServers_userconfig_name = __('User preferences storage table');
 $strConfigServers_users_desc = __(
     'Both this table and the user groups table are required to enable the ' .
-    'configurable menus feature; leaving either one of them blank will disable
-    this feature, suggested: [kbd]pma__users[/kbd].'
+    'configurable menus feature; leaving either one of them blank will disable ' .
+    'this feature, suggested: [kbd]pma__users[/kbd].'
 );
 $strConfigServers_users_name = __('Users table');
 $strConfigServers_usergroups_desc = __(
@@ -871,11 +865,6 @@ $strConfigShowFunctionFields_desc = __(
 $strConfigShowFunctionFields_name = __('Show function fields');
 $strConfigShowHint_desc = __('Whether to show hint or not.');
 $strConfigShowHint_name = __('Show hint');
-$strConfigShowPhpInfo_desc = __(
-    'Shows link to [a@https://php.net/manual/function.phpinfo.php]phpinfo()[/a] ' .
-    'output.'
-);
-$strConfigShowPhpInfo_name = __('Show phpinfo() link');
 $strConfigShowServerInfo_name = __('Show detailed MySQL server information');
 $strConfigShowSQL_desc = __(
     'Defines whether SQL queries generated by phpMyAdmin should be displayed.'
