@@ -37,7 +37,10 @@ function PMA_getPlugin(
     if (is_file($plugins_dir . $file)) {
         //include_once $plugins_dir . $file;
         $fqnClass = 'PMA\\' . str_replace('/', '\\', $plugins_dir) . $class_name;
-        return new $fqnClass;
+        // check if class exists, could be caused by skip_import
+        if (class_exists($fqnClass)) {
+            return new $fqnClass;
+        }
     }
 
     return null;
@@ -76,7 +79,7 @@ function PMA_getPlugins($plugin_type, $plugins_dir, $plugin_param)
         // with ".php"
         if (is_file($plugins_dir . $file)
             && preg_match(
-                '@^' . $class_type . '(.+)\.php$@i',
+                '@^' . $class_type . '([^\.]+)\.php$@i',
                 $file,
                 $matches
             )
