@@ -120,6 +120,10 @@ class Parser
             'class'             => 'SqlParser\\Components\\UnionKeyword',
             'field'             => 'union',
         ),
+        'UNION DISTINCT'        => array(
+            'class'             => 'SqlParser\\Components\\UnionKeyword',
+            'field'             => 'union',
+        ),
 
         // Actual clause parsers.
         'ALTER'                 => array(
@@ -185,6 +189,11 @@ class Parser
             'class'             => 'SqlParser\\Components\\JoinKeyword',
             'field'             => 'join',
         ),
+        'ON'                    => array(
+            'class'             => 'SqlParser\\Components\\Expression',
+            'field'             => 'table',
+            'options'           => array('parseField' => 'table'),
+        ),
         'RIGHT JOIN'            => array(
             'class'             => 'SqlParser\\Components\\JoinKeyword',
             'field'             => 'join',
@@ -201,6 +210,10 @@ class Parser
             'class'             => 'SqlParser\\Components\\JoinKeyword',
             'field'             => 'join',
         ),
+        'FULL OUTER JOIN'       => array(
+            'class'             => 'SqlParser\\Components\\JoinKeyword',
+            'field'             => 'join',
+        ),
         'STRAIGHT_JOIN'         => array(
             'class'             => 'SqlParser\\Components\\JoinKeyword',
             'field'             => 'join',
@@ -422,7 +435,7 @@ class Parser
                 continue;
             }
 
-            if (($token->value === 'UNION') || ($token->value === 'UNION ALL')) {
+            if (($token->value === 'UNION') || ($token->value === 'UNION ALL') || ($token->value === 'UNION DISTINCT')) {
                 $unionType = $token->value;
                 continue;
             }
