@@ -301,7 +301,7 @@ if ($GLOBALS['is_ajax_request']
     && (! isset($_REQUEST['submit_mult']) || $_REQUEST['submit_mult'] != 'export')
     && ((! isset($_REQUEST['initial']) || $_REQUEST['initial'] === null
     || $_REQUEST['initial'] === '')
-    || (isset($_REQUEST['delete']) && $_REQUEST['delete'] === 'Go'))
+    || (isset($_REQUEST['delete']) && $_REQUEST['delete'] === __('Go')))
     && ! isset($_REQUEST['showall'])
     && ! isset($_REQUEST['edit_user_group_dialog'])
     && ! isset($_REQUEST['db_specific'])
