@@ -9,22 +9,19 @@
 /*
  * Include to test.
  */
-require_once 'libraries/insert_edit.lib.php';
+use PMA\libraries\Table;
+use PMA\libraries\Theme;
+use PMA\libraries\Tracker;
+use PMA\libraries\Types;
+use PMA\libraries\TypesMySQL;
 
+require_once 'libraries/insert_edit.lib.php';
 require_once 'libraries/database_interface.inc.php';
-require_once 'libraries/Util.class.php';
 require_once 'libraries/url_generating.lib.php';
-require_once 'libraries/php-gettext/gettext.inc';
-require_once 'libraries/Types.class.php';
 require_once 'libraries/js_escape.lib.php';
 require_once 'libraries/relation.lib.php';
-require_once 'libraries/Message.class.php';
 require_once 'libraries/transformations.lib.php';
-require_once 'libraries/Theme.class.php';
-require_once 'libraries/Response.class.php';
 require_once 'libraries/sanitizing.lib.php';
-require_once 'libraries/Table.class.php';
-require_once 'libraries/Tracker.class.php';
 
 /**
  * Tests for libraries/insert_edit.lib.php
@@ -42,17 +39,14 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
     public function setup()
     {
         $GLOBALS['server'] = 1;
-        $_SESSION['PMA_Theme'] = PMA_Theme::load('./themes/pmahomme');
+        $_SESSION['PMA_Theme'] = Theme::load('./themes/pmahomme');
         $GLOBALS['pmaThemeImage'] = 'theme/';
         $GLOBALS['PMA_PHP_SELF'] = 'index.php';
         $GLOBALS['cfg']['ServerDefault'] = 1;
-        $GLOBALS['available_languages']= array(
-            "en" => array("English", "US-ENGLISH")
-        );
         $GLOBALS['text_dir'] = 'ltr';
         $GLOBALS['db'] = 'db';
         $GLOBALS['table'] = 'table';
-        $GLOBALS['PMA_Types'] = new PMA_Types_MySQL();
+        $GLOBALS['PMA_Types'] = new TypesMySQL();
         $GLOBALS['cfg']['LimitChars'] = 50;
         $GLOBALS['cfg']['LongtextDoubleTextarea'] = false;
         $GLOBALS['cfg']['ShowFieldTypesInDataEditView'] = true;
@@ -64,6 +58,16 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $GLOBALS['cfg']['TextareaCols'] = 4;
         $GLOBALS['cfg']['CharTextareaRows'] = 5;
         $GLOBALS['cfg']['CharTextareaCols'] = 6;
+        $GLOBALS['cfg']['AllowThirdPartyFraming'] = false;
+        $GLOBALS['cfg']['SendErrorReports'] = 'ask';
+        $GLOBALS['cfg']['DefaultTabDatabase'] = 'structure';
+        $GLOBALS['cfg']['ShowDatabasesNavigationAsTree'] = true;
+        $GLOBALS['cfg']['DefaultTabTable'] = 'browse';
+        $GLOBALS['cfg']['NavigationTreeDefaultTabTable'] = 'structure';
+        $GLOBALS['cfg']['NavigationTreeDefaultTabTable2'] = '';
+        $GLOBALS['cfg']['Confirm'] = true;
+        $GLOBALS['cfg']['LoginCookieValidity'] = 1440;
+        $GLOBALS['PMA_Config'] = new PMA\libraries\Config();
     }
 
     /**
@@ -129,7 +133,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
     {
         $clauses = array('a=1', 'b="fo\o"');
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -138,7 +142,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             ->with(
                 'SELECT * FROM `db`.`table` WHERE a=1;',
                 null,
-                PMA_DatabaseInterface::QUERY_STORE
+                PMA\libraries\DatabaseInterface::QUERY_STORE
             )
             ->will($this->returnValue('result1'));
 
@@ -147,7 +151,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             ->with(
                 'SELECT * FROM `db`.`table` WHERE b="fo\o";',
                 null,
-                PMA_DatabaseInterface::QUERY_STORE
+                PMA\libraries\DatabaseInterface::QUERY_STORE
             )
             ->will($this->returnValue('result2'));
 
@@ -192,7 +196,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $temp->primary_key = 1;
         $meta_arr = array($temp);
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -213,13 +217,13 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         // case 2
         $GLOBALS['cfg']['ShowSQL'] = false;
 
-        $responseMock = $this->getMockBuilder('PMA_Response')
+        $responseMock = $this->getMockBuilder('PMA\libraries\Response')
             ->disableOriginalConstructor()
             ->setMethods(array('addHtml'))
             ->getMock();
 
-        $restoreInstance = PMA_Response::getInstance();
-        $response = new ReflectionProperty('PMA_Response', '_instance');
+        $restoreInstance = PMA\libraries\Response::getInstance();
+        $response = new ReflectionProperty('PMA\libraries\Response', '_instance');
         $response->setAccessible(true);
         $response->setValue($responseMock);
 
@@ -241,7 +245,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
     {
         $GLOBALS['cfg']['InsertRows'] = 2;
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -250,7 +254,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             ->with(
                 'SELECT * FROM `db`.`table` LIMIT 1;',
                 null,
-                PMA_DatabaseInterface::QUERY_STORE
+                PMA\libraries\DatabaseInterface::QUERY_STORE
             )
             ->will($this->returnValue('result1'));
 
@@ -596,7 +600,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             )
         );
 
-        $GLOBALS['PMA_Types'] = new PMA_Types;
+        $GLOBALS['PMA_Types'] = new Types;
         $column['Field'] = 'num';
         $this->assertContains(
             '<select name="funcsa" b tabindex="5" id="field_3_1"',
@@ -1657,7 +1661,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         );
 
         // Case 3 (bit)
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -1821,7 +1825,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $_REQUEST['insert_rows'] = 5;
         $GLOBALS['cfg']['InsertRows'] = 2;
 
-        $scriptsMock = $this->getMockBuilder('PMA_Scripts')
+        $scriptsMock = $this->getMockBuilder('PMA\libraries\Scripts')
             ->disableOriginalConstructor()
             ->setMethods(array('addFile'))
             ->getMock();
@@ -1829,7 +1833,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $scriptsMock->expects($this->once())
             ->method('addFile');
 
-        $headerMock = $this->getMockBuilder('PMA_Header')
+        $headerMock = $this->getMockBuilder('PMA\libraries\Header')
             ->disableOriginalConstructor()
             ->setMethods(array('getScripts'))
             ->getMock();
@@ -1838,7 +1842,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             ->method('getScripts')
             ->will($this->returnValue($scriptsMock));
 
-        $responseMock = $this->getMockBuilder('PMA_Response')
+        $responseMock = $this->getMockBuilder('PMA\libraries\Response')
             ->disableOriginalConstructor()
             ->setMethods(array('getHeader'))
             ->getMock();
@@ -1847,8 +1851,8 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             ->method('getHeader')
             ->will($this->returnValue($headerMock));
 
-        $restoreInstance = PMA_Response::getInstance();
-        $response = new ReflectionProperty('PMA_Response', '_instance');
+        $restoreInstance = PMA\libraries\Response::getInstance();
+        $response = new ReflectionProperty('PMA\libraries\Response', '_instance');
         $response->setAccessible(true);
         $response->setValue($responseMock);
 
@@ -1876,7 +1880,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $row = array('1' => 1);
         $res = 'foobar';
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2001,7 +2005,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $GLOBALS['cfg']['IgnoreMultiSubmitErrors'] = false;
         $_REQUEST['submit_type'] = '';
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2046,12 +2050,12 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         );
 
         $this->assertInstanceOf(
-            'PMA_Message',
+            'PMA\libraries\Message',
             $result[2][0]
         );
 
         $msg = $result[2][0];
-        $reflectionMsg = new ReflectionProperty('PMA_Message', 'params');
+        $reflectionMsg = new ReflectionProperty('PMA\libraries\Message', 'params');
         $reflectionMsg->setAccessible(true);
 
         $this->assertEquals(
@@ -2087,7 +2091,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $GLOBALS['cfg']['IgnoreMultiSubmitErrors'] = true;
         $_REQUEST['submit_type'] = '';
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2132,12 +2136,12 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         );
 
         $this->assertInstanceOf(
-            'PMA_Message',
+            'PMA\libraries\Message',
             $result[2][0]
         );
 
         $msg = $result[2][0];
-        $reflectionMsg = new ReflectionProperty('PMA_Message', 'params');
+        $reflectionMsg = new ReflectionProperty('PMA\libraries\Message', 'params');
         $reflectionMsg->setAccessible(true);
 
         $this->assertEquals(
@@ -2173,7 +2177,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             array('Level' => 2, 'Code' => 43, 'Message' => 'msg2'),
         );
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2206,7 +2210,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $map['f']['foreign_table'] = 'TABLES';
         $map['f']['foreign_field'] = 'f';
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2216,7 +2220,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
                 'SELECT `TABLE_COMMENT` FROM `information_schema`.`TABLES` WHERE '
                 . '`f`=1',
                 null,
-                PMA_DatabaseInterface::QUERY_STORE
+                PMA\libraries\DatabaseInterface::QUERY_STORE
             )
             ->will($this->returnValue('r1'));
 
@@ -2288,7 +2292,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         );
         $result = PMA_transformEditedValues(
             'db', 'table', $transformation, $edited_values,
-            'Text_Plain_Preappend.class.php', 'c', array('a' => 'b'),
+            'Text_Plain_PreApPend.php', 'c', array('a' => 'b'),
             'transformation'
         );
 
@@ -2377,7 +2381,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         // case 2
         $multi_edit_funcs = array('UUID');
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2431,7 +2435,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $prow = array();
         $prow['a'] = b'101';
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2565,7 +2569,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $meta = new stdClass();
         $_REQUEST['where_clause'][0] = 1;
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2649,7 +2653,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
      */
     public function testGetTableColumns()
     {
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2679,7 +2683,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
      */
     public function testDetermineInsertOrEdit()
     {
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2693,13 +2697,13 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
         $GLOBALS['cfg']['ShowSQL'] = false;
         $_REQUEST['default_action'] = 'insert';
 
-        $responseMock = $this->getMockBuilder('PMA_Response')
+        $responseMock = $this->getMockBuilder('PMA\libraries\Response')
             ->disableOriginalConstructor()
             ->setMethods(array('addHtml'))
             ->getMock();
 
-        $restoreInstance = PMA_Response::getInstance();
-        $response = new ReflectionProperty('PMA_Response', '_instance');
+        $restoreInstance = PMA\libraries\Response::getInstance();
+        $response = new ReflectionProperty('PMA\libraries\Response', '_instance');
         $response->setAccessible(true);
         $response->setValue($responseMock);
 
@@ -2752,7 +2756,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
     {
         $GLOBALS['cfg']['ShowPropertyComments'] = false;
 
-        $dbi = $this->getMockBuilder('PMA_DatabaseInterface')
+        $dbi = $this->getMockBuilder('PMA\libraries\DatabaseInterface')
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -2769,7 +2773,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             ->method('getTable')
             ->will(
                 $this->returnValue(
-                    new PMA_Table('table', 'db')
+                    new Table('table', 'db')
                 )
             );
 
@@ -2851,7 +2855,7 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             md5('col') => 'val'
         );
         $column_mime = array(
-            'input_transformation' => 'input/Image_JPEG_Upload.class.php',
+            'input_transformation' => 'input/Image_JPEG_Upload.php',
             'input_transformation_options' => '150'
         );
 
@@ -3073,27 +3077,5 @@ class PMA_InsertEditTest extends PHPUnit_Framework_TestCase
             'bar',
             $actual
         );
-
-        // Drizzle
-        $table_columns = array(
-            array(
-                'Field' => 'foo',
-                'Type' => 'longtext',
-                'Null' => 'Yes',
-                'pma_type' => 'longtext',
-                'True_Type' => 'longtext',
-                'Privileges' => null,
-            )
-        );
-        $actual = PMA_getHtmlForInsertEditRow(
-            array(), $table_columns, array(), false, array(), '', '',
-            '', false, array(), $o_rows, $tabindex, 1, false, 0,
-            array(), 0, 0, 'table', 'db', 0, array(), 0, '',
-            array(), array('wc')
-        );
-        $this->assertContains(
-            'foo',
-            $actual
-        );
     }
 }
