@@ -118,10 +118,16 @@ class PMA_ZipExtension_Test extends PHPUnit_Framework_TestCase
     public function testZipExtract()
     {
         $this->assertEquals(
+            false,
             PMA_zipExtract(
-                './test/test_data/test.zip', './test/test_data/', 'wrongName'
-            ),
-            true
+                './test/test_data/test.zip', 'wrongName'
+            )
+        );
+        $this->assertEquals(
+            "TEST FILE\n",
+            PMA_zipExtract(
+                './test/test_data/test.zip', 'test.file'
+            )
         );
     }
 
